==> cheese-2.26.0-i486-1sys.tgz: install/doinst.sh <==
if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime &> /dev/null
fi

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database &> /dev/null
fi

if [ -x /usr/bin/gtk-update-icon-cache ]; then
  /usr/bin/gtk-update-icon-cache  -f -q /usr/share/icons/hicolor &> /dev/null
fi

#
( cd usr/share/gnome/help/cheese/oc/figures ; rm -rf cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/oc/figures ; ln -sf ../../C/figures/cheese-screenshot.jpg cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/oc/figures ; rm -rf cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/oc/figures ; ln -sf ../../C/figures/cheese-effects-screenshot.jpg cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/fr/figures ; rm -rf cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/fr/figures ; ln -sf ../../C/figures/cheese-effects-screenshot.jpg cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/en_GB/figures ; rm -rf cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/en_GB/figures ; ln -sf ../../C/figures/cheese-screenshot.jpg cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/en_GB/figures ; rm -rf cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/en_GB/figures ; ln -sf ../../C/figures/cheese-effects-screenshot.jpg cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/el/figures ; rm -rf cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/el/figures ; ln -sf ../../C/figures/cheese-screenshot.jpg cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/el/figures ; rm -rf cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/el/figures ; ln -sf ../../C/figures/cheese-effects-screenshot.jpg cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/ru/figures ; rm -rf cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/ru/figures ; ln -sf ../../C/figures/cheese-screenshot.jpg cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/ru/figures ; rm -rf cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/ru/figures ; ln -sf ../../C/figures/cheese-effects-screenshot.jpg cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/de/figures ; rm -rf cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/de/figures ; ln -sf ../../C/figures/cheese-screenshot.jpg cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/de/figures ; rm -rf cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/de/figures ; ln -sf ../../C/figures/cheese-effects-screenshot.jpg cheese-effects-screenshot.jpg )

==> cheese-2.27.91-i486-1sys.tgz: install/doinst.sh <==
if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime &> /dev/null
fi

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database &> /dev/null
fi

if [ -x /usr/bin/gtk-update-icon-cache ]; then
  /usr/bin/gtk-update-icon-cache  -f -q /usr/share/icons/hicolor &> /dev/null
fi
	# Update the scrollkeeper database (Remove stale pieces)
	if [ -x usr/bin/scrollkeeper-update ]; then
		usr/bin/scrollkeeper-update > /dev/null 2>&1
	fi
#
( cd usr/share/gnome/help/cheese/oc/figures ; rm -rf cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/oc/figures ; ln -sf ../../C/figures/cheese-screenshot.jpg cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/oc/figures ; rm -rf cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/oc/figures ; ln -sf ../../C/figures/cheese-effects-screenshot.jpg cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/en_GB/figures ; rm -rf cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/en_GB/figures ; ln -sf ../../C/figures/cheese-screenshot.jpg cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/en_GB/figures ; rm -rf cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/en_GB/figures ; ln -sf ../../C/figures/cheese-effects-screenshot.jpg cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/it/figures ; rm -rf cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/it/figures ; ln -sf ../../C/figures/cheese-screenshot.jpg cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/it/figures ; rm -rf cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/it/figures ; ln -sf ../../C/figures/cheese-effects-screenshot.jpg cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/ru/figures ; rm -rf cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/ru/figures ; ln -sf ../../C/figures/cheese-screenshot.jpg cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/ru/figures ; rm -rf cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/ru/figures ; ln -sf ../../C/figures/cheese-effects-screenshot.jpg cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/el/figures ; rm -rf cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/el/figures ; ln -sf ../../C/figures/cheese-screenshot.jpg cheese-screenshot.jpg )
( cd usr/share/gnome/help/cheese/el/figures ; rm -rf cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/el/figures ; ln -sf ../../C/figures/cheese-effects-screenshot.jpg cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/fr/figures ; rm -rf cheese-effects-screenshot.jpg )
( cd usr/share/gnome/help/cheese/fr/figures ; ln -sf ../../C/figures/cheese-effects-screenshot.jpg cheese-effects-screenshot.jpg )
